@@ -76,7 +76,7 @@ def load(self, options = dict()):
         if device.source == 'api':
 
             if device.location is None:
-                device.location = device.api_device.get_device_location()
+                device.location = device.api_device.get_device_timezone()
 
             # Get last reading from API
             if 'get_device_last_reading' in dir(device.api_device): 
@@ -202,4 +202,5 @@ def load(self, options = dict()):
         else: std_out(f'Could not load device {device.id}. Skipping', 'WARNING')
 
     self.__update_descriptor__()
-    std_out('Test load done', 'SUCCESS')
\ No newline at end of file
+    std_out('Test load done', 'SUCCESS')
+    self.loaded = True
\ No newline at end of file
