@@ -37,7 +37,7 @@ def scatter_plot(self, **kwargs):
         Matplotlib figure and axes
     """
 
-    if config._framework == 'jupyterlab': plt.ioff();
+    if config.framework == 'jupyterlab': plt.ioff();
     plt.clf();
 
     if 'traces' not in kwargs: 
