@@ -33,7 +33,7 @@ def ts_iplot(self, **kwargs):
         Plotly figure
     """
 
-    if config._framework == 'jupyterlab': renderers.default = config._framework
+    if config.framework == 'jupyterlab': renderers.default = config.framework
 
     if 'traces' not in kwargs:
         std_out('No traces defined', 'ERROR')
