@@ -1,8 +1,13 @@
 from termcolor import colored
 from scdata._config import config
+from datetime import datetime
 
 def std_out(msg, mtype = None, force = False):
     out_level = config._out_level
+    if config._timestamp == True:
+        stamp = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        stamp = ''
     # Output levels:
     # 'QUIET': nothing, 
     # 'NORMAL': warn, err
@@ -13,10 +18,10 @@ def std_out(msg, mtype = None, force = False):
     elif out_level == 'DEBUG': priority = 2
 
     if mtype is None and priority>1: 
-        print('[INFO]: ' + msg)
+        print(f'[{stamp}] - ' + '[INFO] ' + msg)
     elif mtype == 'SUCCESS' and priority>0: 
-        print(colored('[SUCCESS]: ', 'green') + msg)
+        print(f'[{stamp}] - ' + colored('[SUCCESS] ', 'green') + msg)
     elif mtype == 'WARNING' and priority>0: 
-        print(colored('[WARNING]: ', 'yellow') + msg)
+        print(f'[{stamp}] - ' + colored('[WARNING] ', 'yellow') + msg)
     elif mtype == 'ERROR' and priority>0: 
-        print(colored('[ERROR]: ', 'red') + msg)
\ No newline at end of file
+        print(f'[{stamp}] - ' + colored('[ERROR] ', 'red') + msg)
\ No newline at end of file
